@@ -8,8 +8,7 @@ class Util
     public:
         static bool mkdir(std::string const &path); // pathname to a file
                                                     // find full path name
-        static std::string makeAbsPath(std::string const &path);   
-
+        static std::string realPath(std::string const &path);   
 };
     
 #endif
